@@ -3,4 +3,7 @@ def sumaSimple(num, num2):
   return num + num2
 
 def restSimple(num, num2):
-  return num - num2
\ No newline at end of file
+  return num - num2
+
+def mulSimple(num, num2):
+  return num * num2
\ No newline at end of file
